# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1.asymmetricencryption import asymmetric_encryption_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1aHyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key.proto\"\xde\x03\n$CreateAsymmetricEncryptionKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\xa7\x01\n\x06labels\x18\x04 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x65\n\x14\x65ncryption_algorithm\x18\x05 \x01(\x0e\x32G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%CreateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"A\n!GetAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x84\x01\n#ListAsymmetricEncryptionKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x90\x01\n$ListAsymmetricEncryptionKeysResponse\x12O\n\x04keys\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x04\n$UpdateAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12X\n\x06status\x18\x05 \x01(\x0e\x32H.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey.Status\x12\xa7\x01\n\x06labels\x18\x06 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"D\n$DeleteAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x8a\x01\n,ListAsymmetricEncryptionKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x7f\n-ListAsymmetricEncryptionKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd0\x10\n\x1e\x41symmetricEncryptionKeyService\x12\xec\x01\n\x06\x43reate\x12N.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*@\n%CreateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x82\xd3\xe4\x93\x02%\" /kms/v1/asymmetricEncryptionKeys:\x01*\x12\xc8\x01\n\x03Get\x12K.yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest\x1a\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\"1\x82\xd3\xe4\x93\x02+\x12)/kms/v1/asymmetricEncryptionKeys/{key_id}\x12\xcf\x01\n\x04List\x12M.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest\x1aN.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /kms/v1/asymmetricEncryptionKeys\x12\xf5\x01\n\x06Update\x12N.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*@\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x82\xd3\xe4\x93\x02.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\x01*\x12\xf2\x01\n\x06\x44\x65lete\x12N.yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*@\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x82\xd3\xe4\x93\x02+*)/kms/v1/asymmetricEncryptionKeys/{key_id}\x12\xff\x01\n\x0eListOperations\x12V.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest\x1aW.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/kms/v1/asymmetricEncryptionKeys/{key_id}/operations\x12\xc0\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings\x12\xf0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\x01*\x12\xfc\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\x01*Bk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_GETASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_GETASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_DELETEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_DELETEASYMMETRICENCRYPTIONKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*@\n%CreateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey\202\323\344\223\002%\" /kms/v1/asymmetricEncryptionKeys:\001*'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/kms/v1/asymmetricEncryptionKeys/{key_id}'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /kms/v1/asymmetricEncryptionKeys'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*@\n%UpdateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey\202\323\344\223\002.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\001*'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*@\n%DeleteAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey\202\323\344\223\002+*)/kms/v1/asymmetricEncryptionKeys/{key_id}'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/kms/v1/asymmetricEncryptionKeys/{key_id}/operations'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002C\022A/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\001*'
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\001*'
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_start=404
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_end=882
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_start=837
  _globals['_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_end=882
  _globals['_CREATEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_start=884
  _globals['_CREATEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_end=939
  _globals['_GETASYMMETRICENCRYPTIONKEYREQUEST']._serialized_start=941
  _globals['_GETASYMMETRICENCRYPTIONKEYREQUEST']._serialized_end=1006
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST']._serialized_start=1009
  _globals['_LISTASYMMETRICENCRYPTIONKEYSREQUEST']._serialized_end=1141
  _globals['_LISTASYMMETRICENCRYPTIONKEYSRESPONSE']._serialized_start=1144
  _globals['_LISTASYMMETRICENCRYPTIONKEYSRESPONSE']._serialized_end=1288
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_start=1291
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_end=1808
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_start=837
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY']._serialized_end=882
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_start=1810
  _globals['_UPDATEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_end=1865
  _globals['_DELETEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_start=1867
  _globals['_DELETEASYMMETRICENCRYPTIONKEYREQUEST']._serialized_end=1935
  _globals['_DELETEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_start=1937
  _globals['_DELETEASYMMETRICENCRYPTIONKEYMETADATA']._serialized_end=1992
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST']._serialized_start=1995
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST']._serialized_end=2133
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE']._serialized_start=2135
  _globals['_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE']._serialized_end=2262
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE']._serialized_start=2265
  _globals['_ASYMMETRICENCRYPTIONKEYSERVICE']._serialized_end=4393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/elasticsearch/v1/auth_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/elasticsearch/v1/auth_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/elasticsearch/v1/auth_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/elasticsearch/v1/auth.proto\"<\n\x18ListAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"_\n\x19ListAuthProvidersResponse\x12\x42\n\tproviders\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"j\n\x16GetAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\"\x89\x01\n\x17\x41\x64\x64\x41uthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"\x8c\x01\n\x1aUpdateAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"|\n\x1a\x44\x65leteAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0eprovider_names\x18\x02 \x03(\tB$\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\"\xb6\x01\n\x19UpdateAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\x12G\n\x08provider\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x04\xe8\xc7\x31\x01\"m\n\x19\x44\x65leteAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\"=\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1bUpdateAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t2\xef\x0c\n\x0b\x41uthService\x12\xd2\x01\n\rListProviders\x12;.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest\x1a<.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\x12\xc8\x01\n\x0bGetProvider\x12\x39.yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest\x1a/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"M\x82\xd3\xe4\x93\x02G\x12\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}\x12\xe5\x01\n\x0c\x41\x64\x64Providers\x12:.yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*)\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02\x43\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\x12\xee\x01\n\x0fUpdateProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02\x43\x1a>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\x12\xf3\x01\n\x0f\x44\x65leteProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\x12\xf4\x01\n\x0eUpdateProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02J\x1a\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\x01*\x12\xf9\x01\n\x0e\x44\x65leteProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _globals['_LISTAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['providers']._loaded_options = None
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['providers']._serialized_options = b'\202\3101\004<=10'
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['providers']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['providers']._serialized_options = b'\202\3101\004<=10'
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['provider_names']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['provider_names']._serialized_options = b'\362\3071\020[a-z][a-z0-9_-]*\202\3101\004<=10\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['provider']._serialized_options = b'\350\3071\001'
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_AUTHSERVICE'].methods_by_name['ListProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['ListProviders']._serialized_options = b'\202\323\344\223\002@\022>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers'
  _globals['_AUTHSERVICE'].methods_by_name['GetProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['GetProvider']._serialized_options = b'\202\323\344\223\002G\022E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}'
  _globals['_AUTHSERVICE'].methods_by_name['AddProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['AddProviders']._serialized_options = b'\262\322*)\n\030AddAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002C\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProviders']._serialized_options = b'\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002C\032>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProviders']._serialized_options = b'\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers'
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProvider']._serialized_options = b'\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002J\032E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProvider']._serialized_options = b'\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}'
  _globals['_LISTAUTHPROVIDERSREQUEST']._serialized_start=272
  _globals['_LISTAUTHPROVIDERSREQUEST']._serialized_end=332
  _globals['_LISTAUTHPROVIDERSRESPONSE']._serialized_start=334
  _globals['_LISTAUTHPROVIDERSRESPONSE']._serialized_end=429
  _globals['_GETAUTHPROVIDERREQUEST']._serialized_start=431
  _globals['_GETAUTHPROVIDERREQUEST']._serialized_end=537
  _globals['_ADDAUTHPROVIDERSREQUEST']._serialized_start=540
  _globals['_ADDAUTHPROVIDERSREQUEST']._serialized_end=677
  _globals['_UPDATEAUTHPROVIDERSREQUEST']._serialized_start=680
  _globals['_UPDATEAUTHPROVIDERSREQUEST']._serialized_end=820
  _globals['_DELETEAUTHPROVIDERSREQUEST']._serialized_start=822
  _globals['_DELETEAUTHPROVIDERSREQUEST']._serialized_end=946
  _globals['_UPDATEAUTHPROVIDERREQUEST']._serialized_start=949
  _globals['_UPDATEAUTHPROVIDERREQUEST']._serialized_end=1131
  _globals['_DELETEAUTHPROVIDERREQUEST']._serialized_start=1133
  _globals['_DELETEAUTHPROVIDERREQUEST']._serialized_end=1242
  _globals['_ADDAUTHPROVIDERSMETADATA']._serialized_start=1244
  _globals['_ADDAUTHPROVIDERSMETADATA']._serialized_end=1305
  _globals['_UPDATEAUTHPROVIDERSMETADATA']._serialized_start=1307
  _globals['_UPDATEAUTHPROVIDERSMETADATA']._serialized_end=1371
  _globals['_DELETEAUTHPROVIDERSMETADATA']._serialized_start=1373
  _globals['_DELETEAUTHPROVIDERSMETADATA']._serialized_end=1437
  _globals['_AUTHSERVICE']._serialized_start=1440
  _globals['_AUTHSERVICE']._serialized_end=3087
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Trail(google.protobuf.message.Message):
    """Trail describes the filtering and destination configuration of the process of sending Audit events"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trail._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Trail._Status.ValueType  # 0
        ACTIVE: Trail._Status.ValueType  # 1
        """The trail is active and Audit events are processed"""
        ERROR: Trail._Status.ValueType  # 2
        """The trail configuration has issues that are preventing Audit Trails from delivering events"""
        DELETED: Trail._Status.ValueType  # 3
        """The trail is being deleted"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Trail.Status.ValueType  # 0
    ACTIVE: Trail.Status.ValueType  # 1
    """The trail is active and Audit events are processed"""
    ERROR: Trail.Status.ValueType  # 2
    """The trail configuration has issues that are preventing Audit Trails from delivering events"""
    DELETED: Trail.Status.ValueType  # 3
    """The trail is being deleted"""

    class _EventCategoryFilter:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EventCategoryFilterEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trail._EventCategoryFilter.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EVENT_CATEGORY_FILTER_UNSPECIFIED: Trail._EventCategoryFilter.ValueType  # 0
        CONTROL_PLANE: Trail._EventCategoryFilter.ValueType  # 1
        """The events that are generated during the interaction with the service's resources"""
        DATA_PLANE: Trail._EventCategoryFilter.ValueType  # 2
        """Events that are generated during interaction with data within the service's resources"""

    class EventCategoryFilter(_EventCategoryFilter, metaclass=_EventCategoryFilterEnumTypeWrapper): ...
    EVENT_CATEGORY_FILTER_UNSPECIFIED: Trail.EventCategoryFilter.ValueType  # 0
    CONTROL_PLANE: Trail.EventCategoryFilter.ValueType  # 1
    """The events that are generated during the interaction with the service's resources"""
    DATA_PLANE: Trail.EventCategoryFilter.ValueType  # 2
    """Events that are generated during interaction with data within the service's resources"""

    class _EventAccessTypeFilter:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EventAccessTypeFilterEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trail._EventAccessTypeFilter.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EVENT_ACCESS_TYPE_FILTER_UNSPECIFIED: Trail._EventAccessTypeFilter.ValueType  # 0
        WRITE: Trail._EventAccessTypeFilter.ValueType  # 1
        """Events for operations that do perform some modification"""
        READ: Trail._EventAccessTypeFilter.ValueType  # 2
        """Events for operations that do not perform any modifications"""

    class EventAccessTypeFilter(_EventAccessTypeFilter, metaclass=_EventAccessTypeFilterEnumTypeWrapper): ...
    EVENT_ACCESS_TYPE_FILTER_UNSPECIFIED: Trail.EventAccessTypeFilter.ValueType  # 0
    WRITE: Trail.EventAccessTypeFilter.ValueType  # 1
    """Events for operations that do perform some modification"""
    READ: Trail.EventAccessTypeFilter.ValueType  # 2
    """Events for operations that do not perform any modifications"""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Destination(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        OBJECT_STORAGE_FIELD_NUMBER: builtins.int
        CLOUD_LOGGING_FIELD_NUMBER: builtins.int
        DATA_STREAM_FIELD_NUMBER: builtins.int
        @property
        def object_storage(self) -> global___Trail.ObjectStorage:
            """Configuration for event delivery to Object Storage

            Uploaded objects will have prefix <trail_id>/ by default
            """

        @property
        def cloud_logging(self) -> global___Trail.CloudLogging:
            """Configuration for event delivery to Cloud Logging"""

        @property
        def data_stream(self) -> global___Trail.DataStream:
            """Configuration for event delivery to YDS"""

        def __init__(
            self,
            *,
            object_storage: global___Trail.ObjectStorage | None = ...,
            cloud_logging: global___Trail.CloudLogging | None = ...,
            data_stream: global___Trail.DataStream | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["cloud_logging", b"cloud_logging", "data_stream", b"data_stream", "destination", b"destination", "object_storage", b"object_storage"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["cloud_logging", b"cloud_logging", "data_stream", b"data_stream", "destination", b"destination", "object_storage", b"object_storage"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["object_storage", "cloud_logging", "data_stream"] | None: ...

    @typing.final
    class ObjectStorage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUCKET_ID_FIELD_NUMBER: builtins.int
        OBJECT_PREFIX_FIELD_NUMBER: builtins.int
        bucket_id: builtins.str
        """Name of the destination bucket"""
        object_prefix: builtins.str
        """Prefix for exported objects. Optional
        If specified, uploaded objects will have prefix <object_prefix>/<trail_id>/
        """
        def __init__(
            self,
            *,
            bucket_id: builtins.str = ...,
            object_prefix: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "object_prefix", b"object_prefix"]) -> None: ...

    @typing.final
    class CloudLogging(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOG_GROUP_ID_FIELD_NUMBER: builtins.int
        log_group_id: builtins.str
        """ID of the Cloud Logging destination group"""
        def __init__(
            self,
            *,
            log_group_id: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["destination", b"destination", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["destination", b"destination", "log_group_id", b"log_group_id"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id"] | None: ...

    @typing.final
    class DataStream(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATABASE_ID_FIELD_NUMBER: builtins.int
        STREAM_NAME_FIELD_NUMBER: builtins.int
        database_id: builtins.str
        """ID of the database hosting the destination YDS"""
        stream_name: builtins.str
        """Name of the destination YDS"""
        def __init__(
            self,
            *,
            database_id: builtins.str = ...,
            stream_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "stream_name", b"stream_name"]) -> None: ...

    @typing.final
    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PATH_FILTER_FIELD_NUMBER: builtins.int
        EVENT_FILTER_FIELD_NUMBER: builtins.int
        @property
        def path_filter(self) -> global___Trail.PathFilter:
            """Configuration of default events gathering for the trail
            If not specified, default events won't be gathered for the trail
            """

        @property
        def event_filter(self) -> global___Trail.EventFilter:
            """Configuration of additional events gathering from specific services"""

        def __init__(
            self,
            *,
            path_filter: global___Trail.PathFilter | None = ...,
            event_filter: global___Trail.EventFilter | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["event_filter", b"event_filter", "path_filter", b"path_filter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["event_filter", b"event_filter", "path_filter", b"path_filter"]) -> None: ...

    @typing.final
    class PathFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ROOT_FIELD_NUMBER: builtins.int
        @property
        def root(self) -> global___Trail.PathFilterElement:
            """Root element of the resource path filter for the trail
            Resource described in that filter node must contain the trail itself
            """

        def __init__(
            self,
            *,
            root: global___Trail.PathFilterElement | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["root", b"root"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["root", b"root"]) -> None: ...

    @typing.final
    class PathFilterElement(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ANY_FILTER_FIELD_NUMBER: builtins.int
        SOME_FILTER_FIELD_NUMBER: builtins.int
        @property
        def any_filter(self) -> global___Trail.PathFilterElementAny:
            """Filter element with ANY type. If used, configures the trail to gather any events from the resource"""

        @property
        def some_filter(self) -> global___Trail.PathFilterElementSome:
            """Filter element with SOME type. If used, configures the trail to gather some of the events from the resource"""

        def __init__(
            self,
            *,
            any_filter: global___Trail.PathFilterElementAny | None = ...,
            some_filter: global___Trail.PathFilterElementSome | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["any_filter", b"any_filter", "element", b"element", "some_filter", b"some_filter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["any_filter", b"any_filter", "element", b"element", "some_filter", b"some_filter"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["element", b"element"]) -> typing.Literal["any_filter", "some_filter"] | None: ...

    @typing.final
    class PathFilterElementAny(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCE_FIELD_NUMBER: builtins.int
        @property
        def resource(self) -> global___Trail.Resource:
            """Resource definition"""

        def __init__(
            self,
            *,
            resource: global___Trail.Resource | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["resource", b"resource"]) -> None: ...

    @typing.final
    class PathFilterElementSome(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCE_FIELD_NUMBER: builtins.int
        FILTERS_FIELD_NUMBER: builtins.int
        @property
        def resource(self) -> global___Trail.Resource:
            """Definition of the resource that contains nested resources"""

        @property
        def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.PathFilterElement]:
            """Filters for the resources contained in the parent resource"""

        def __init__(
            self,
            *,
            resource: global___Trail.Resource | None = ...,
            filters: collections.abc.Iterable[global___Trail.PathFilterElement] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["filters", b"filters", "resource", b"resource"]) -> None: ...

    @typing.final
    class Resource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """ID of the resource"""
        type: builtins.str
        """Type of the resource"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    @typing.final
    class EventFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILTERS_FIELD_NUMBER: builtins.int
        @property
        def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.EventFilterElement]:
            """List of filters for services"""

        def __init__(
            self,
            *,
            filters: collections.abc.Iterable[global___Trail.EventFilterElement] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["filters", b"filters"]) -> None: ...

    @typing.final
    class EventFilterElement(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERVICE_FIELD_NUMBER: builtins.int
        CATEGORIES_FIELD_NUMBER: builtins.int
        PATH_FILTER_FIELD_NUMBER: builtins.int
        service: builtins.str
        """Service ID of the gathered events"""
        @property
        def categories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.EventFilterElementCategory]:
            """List of the event categories gathered for a specified service"""

        @property
        def path_filter(self) -> global___Trail.PathFilter:
            """Resource path filter for a specified service"""

        def __init__(
            self,
            *,
            service: builtins.str = ...,
            categories: collections.abc.Iterable[global___Trail.EventFilterElementCategory] | None = ...,
            path_filter: global___Trail.PathFilter | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["path_filter", b"path_filter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["categories", b"categories", "path_filter", b"path_filter", "service", b"service"]) -> None: ...

    @typing.final
    class EventFilterElementCategory(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PLANE_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        plane: global___Trail.EventCategoryFilter.ValueType
        """Plane of the gathered category"""
        type: global___Trail.EventAccessTypeFilter.ValueType
        """Type of the gathered category"""
        def __init__(
            self,
            *,
            plane: global___Trail.EventCategoryFilter.ValueType = ...,
            type: global___Trail.EventAccessTypeFilter.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["plane", b"plane", "type", b"type"]) -> None: ...

    @typing.final
    class DataEventsFiltering(google.protobuf.message.Message):
        """Policy for gathering data events"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERVICE_FIELD_NUMBER: builtins.int
        INCLUDED_EVENTS_FIELD_NUMBER: builtins.int
        EXCLUDED_EVENTS_FIELD_NUMBER: builtins.int
        DNS_FILTER_FIELD_NUMBER: builtins.int
        RESOURCE_SCOPES_FIELD_NUMBER: builtins.int
        service: builtins.str
        """Name of the service whose events will be delivered"""
        @property
        def included_events(self) -> global___Trail.EventTypes:
            """Explicitly included events of specified service
            New events of the service won't be delivered by default
            """

        @property
        def excluded_events(self) -> global___Trail.EventTypes:
            """Explicitly excluded events of specified service
            New events of the service will be delivered by default
            """

        @property
        def dns_filter(self) -> global___Trail.DnsDataEventsFilter:
            """Filter is allowed only if service = dns"""

        @property
        def resource_scopes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.Resource]:
            """A list of resources which will be monitored by the trail"""

        def __init__(
            self,
            *,
            service: builtins.str = ...,
            included_events: global___Trail.EventTypes | None = ...,
            excluded_events: global___Trail.EventTypes | None = ...,
            dns_filter: global___Trail.DnsDataEventsFilter | None = ...,
            resource_scopes: collections.abc.Iterable[global___Trail.Resource] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["additional_rules", b"additional_rules", "dns_filter", b"dns_filter", "excluded_events", b"excluded_events", "included_events", b"included_events", "service_specific_rules", b"service_specific_rules"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["additional_rules", b"additional_rules", "dns_filter", b"dns_filter", "excluded_events", b"excluded_events", "included_events", b"included_events", "resource_scopes", b"resource_scopes", "service", b"service", "service_specific_rules", b"service_specific_rules"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["additional_rules", b"additional_rules"]) -> typing.Literal["included_events", "excluded_events"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["service_specific_rules", b"service_specific_rules"]) -> typing.Literal["dns_filter"] | None: ...

    @typing.final
    class EventTypes(google.protobuf.message.Message):
        """Policy with explicitly specified event group"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EVENT_TYPES_FIELD_NUMBER: builtins.int
        @property
        def event_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            event_types: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["event_types", b"event_types"]) -> None: ...

    @typing.final
    class ManagementEventsFiltering(google.protobuf.message.Message):
        """Policy for gathering management events"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCE_SCOPES_FIELD_NUMBER: builtins.int
        @property
        def resource_scopes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.Resource]:
            """A list of resources which will be monitored by the trail"""

        def __init__(
            self,
            *,
            resource_scopes: collections.abc.Iterable[global___Trail.Resource] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["resource_scopes", b"resource_scopes"]) -> None: ...

    @typing.final
    class FilteringPolicy(google.protobuf.message.Message):
        """Combination of policies describing event filtering process of the trail
        At least one filed must be filled
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MANAGEMENT_EVENTS_FILTER_FIELD_NUMBER: builtins.int
        DATA_EVENTS_FILTERS_FIELD_NUMBER: builtins.int
        @property
        def management_events_filter(self) -> global___Trail.ManagementEventsFiltering:
            """Singular filter describing gathering management events"""

        @property
        def data_events_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Trail.DataEventsFiltering]:
            """List of filters describing gathering data events"""

        def __init__(
            self,
            *,
            management_events_filter: global___Trail.ManagementEventsFiltering | None = ...,
            data_events_filters: collections.abc.Iterable[global___Trail.DataEventsFiltering] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["management_events_filter", b"management_events_filter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["data_events_filters", b"data_events_filters", "management_events_filter", b"management_events_filter"]) -> None: ...

    @typing.final
    class DnsDataEventsFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ONLY_RECURSIVE_QUERIES_FIELD_NUMBER: builtins.int
        INCLUDE_NONRECURSIVE_QUERIES_FIELD_NUMBER: builtins.int
        only_recursive_queries: builtins.bool
        """deprecated: use all_dns_queries instead"""
        include_nonrecursive_queries: builtins.bool
        """Not only recursive queries will be delivered"""
        def __init__(
            self,
            *,
            only_recursive_queries: builtins.bool = ...,
            include_nonrecursive_queries: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["include_nonrecursive_queries", b"include_nonrecursive_queries", "only_recursive_queries", b"only_recursive_queries"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STATUS_ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FILTERING_POLICY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the trail"""
    folder_id: builtins.str
    """ID of the folder that the trail belongs to"""
    name: builtins.str
    """Name of the trail"""
    description: builtins.str
    """Description of the trail"""
    service_account_id: builtins.str
    """Service account ID of the trail"""
    status: global___Trail.Status.ValueType
    """Status of the trail"""
    status_error_message: builtins.str
    """Current error message of the trail. Empty in case if the trail is active"""
    cloud_id: builtins.str
    """ID of the cloud that the trail belongs to"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp for the creation operation"""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp of the last update operation"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels of the trail as `key:value` pairs. Maximum 64 per key"""

    @property
    def destination(self) -> global___Trail.Destination:
        """Destination configuration of the trail"""

    @property
    def filter(self) -> global___Trail.Filter:
        """Filtering configuration of the trail
        deprecated: use filtering_policy instead
        """

    @property
    def filtering_policy(self) -> global___Trail.FilteringPolicy:
        """Event filtering policy
        Describes which groups of events will be sent and which resources will be monitored
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        destination: global___Trail.Destination | None = ...,
        service_account_id: builtins.str = ...,
        status: global___Trail.Status.ValueType = ...,
        filter: global___Trail.Filter | None = ...,
        status_error_message: builtins.str = ...,
        cloud_id: builtins.str = ...,
        filtering_policy: global___Trail.FilteringPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "destination", b"destination", "filter", b"filter", "filtering_policy", b"filtering_policy", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "destination", b"destination", "filter", b"filter", "filtering_policy", b"filtering_policy", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "service_account_id", b"service_account_id", "status", b"status", "status_error_message", b"status_error_message", "updated_at", b"updated_at"]) -> None: ...

global___Trail = Trail



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/http_router_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/http_router_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import http_router_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_http__router__pb2
from yandex.cloud.apploadbalancer.v1 import virtual_host_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/apploadbalancer/v1/http_router_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x31yandex/cloud/apploadbalancer/v1/http_router.proto\x1a\x32yandex/cloud/apploadbalancer/v1/virtual_host.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x14GetHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8b\x01\n\x16ListHttpRoutersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n\x17ListHttpRoutersResponse\x12\x41\n\x0chttp_routers\x18\x01 \x03(\x0b\x32+.yandex.cloud.apploadbalancer.v1.HttpRouter\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x17\x44\x65leteHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x18\x44\x65leteHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\x9a\x04\n\x17UpdateHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x99\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x43\n\rvirtual_hosts\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x44\n\rroute_options\x18\x08 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"2\n\x18UpdateHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\xe4\x03\n\x17\x43reateHttpRouterRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x43\n\rvirtual_hosts\x18\x05 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x44\n\rroute_options\x18\x07 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"2\n\x18\x43reateHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\x85\x01\n\x1fListHttpRouterOperationsRequest\x12$\n\x0ehttp_router_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n ListHttpRouterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9f\t\n\x11HttpRouterService\x12\xa3\x01\n\x03Get\x12\x35.yandex.cloud.apploadbalancer.v1.GetHttpRouterRequest\x1a+.yandex.cloud.apploadbalancer.v1.HttpRouter\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/apploadbalancer/v1/httpRouters/{http_router_id}\x12\xa2\x01\n\x04List\x12\x37.yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest\x1a\x38.yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/apploadbalancer/v1/httpRouters\x12\xbb\x01\n\x06\x43reate\x12\x38.yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*&\n\x18\x43reateHttpRouterMetadata\x12\nHttpRouter\x82\xd3\xe4\x93\x02$\"\x1f/apploadbalancer/v1/httpRouters:\x01*\x12\xcc\x01\n\x06Update\x12\x38.yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*&\n\x18UpdateHttpRouterMetadata\x12\nHttpRouter\x82\xd3\xe4\x93\x02\x35\x32\x30/apploadbalancer/v1/httpRouters/{http_router_id}:\x01*\x12\xd4\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.apploadbalancer.v1.DeleteHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*1\n\x18\x44\x65leteHttpRouterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32*0/apploadbalancer/v1/httpRouters/{http_router_id}\x12\xda\x01\n\x0eListOperations\x12@.yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest\x1a\x41.yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/apploadbalancer/v1/httpRouters/{http_router_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_GETHTTPROUTERREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_GETHTTPROUTERREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTHTTPROUTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DELETEHTTPROUTERREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_DELETEHTTPROUTERREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEHTTPROUTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEHTTPROUTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEHTTPROUTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEHTTPROUTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/apploadbalancer/v1/httpRouters/{http_router_id}'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/apploadbalancer/v1/httpRouters'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateHttpRouterMetadata\022\nHttpRouter\202\323\344\223\002$\"\037/apploadbalancer/v1/httpRouters:\001*'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateHttpRouterMetadata\022\nHttpRouter\202\323\344\223\002520/apploadbalancer/v1/httpRouters/{http_router_id}:\001*'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteHttpRouterMetadata\022\025google.protobuf.Empty\202\323\344\223\0022*0/apploadbalancer/v1/httpRouters/{http_router_id}'
  _globals['_HTTPROUTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_HTTPROUTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002=\022;/apploadbalancer/v1/httpRouters/{http_router_id}/operations'
  _globals['_GETHTTPROUTERREQUEST']._serialized_start=366
  _globals['_GETHTTPROUTERREQUEST']._serialized_end=418
  _globals['_LISTHTTPROUTERSREQUEST']._serialized_start=421
  _globals['_LISTHTTPROUTERSREQUEST']._serialized_end=560
  _globals['_LISTHTTPROUTERSRESPONSE']._serialized_start=562
  _globals['_LISTHTTPROUTERSRESPONSE']._serialized_end=679
  _globals['_DELETEHTTPROUTERREQUEST']._serialized_start=681
  _globals['_DELETEHTTPROUTERREQUEST']._serialized_end=736
  _globals['_DELETEHTTPROUTERMETADATA']._serialized_start=738
  _globals['_DELETEHTTPROUTERMETADATA']._serialized_end=788
  _globals['_UPDATEHTTPROUTERREQUEST']._serialized_start=791
  _globals['_UPDATEHTTPROUTERREQUEST']._serialized_end=1329
  _globals['_UPDATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_start=1278
  _globals['_UPDATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_end=1323
  _globals['_UPDATEHTTPROUTERMETADATA']._serialized_start=1331
  _globals['_UPDATEHTTPROUTERMETADATA']._serialized_end=1381
  _globals['_CREATEHTTPROUTERREQUEST']._serialized_start=1384
  _globals['_CREATEHTTPROUTERREQUEST']._serialized_end=1868
  _globals['_CREATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_start=1278
  _globals['_CREATEHTTPROUTERREQUEST_LABELSENTRY']._serialized_end=1323
  _globals['_CREATEHTTPROUTERMETADATA']._serialized_start=1870
  _globals['_CREATEHTTPROUTERMETADATA']._serialized_end=1920
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST']._serialized_start=1923
  _globals['_LISTHTTPROUTEROPERATIONSREQUEST']._serialized_end=2056
  _globals['_LISTHTTPROUTEROPERATIONSRESPONSE']._serialized_start=2058
  _globals['_LISTHTTPROUTEROPERATIONSRESPONSE']._serialized_end=2172
  _globals['_HTTPROUTERSERVICE']._serialized_start=2175
  _globals['_HTTPROUTERSERVICE']._serialized_end=3358
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AsymmetricSignRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to use for signature."""
    message: builtins.bytes
    """Message to sign.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        message: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "message", b"message"]) -> None: ...

global___AsymmetricSignRequest = AsymmetricSignRequest

@typing.final
class AsymmetricSignResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key that was used for signature."""
    signature: builtins.bytes
    """Value of signature.
    Signature value is produced in accordance with RFC 8017 for RSA
    and is a DER-encoded object as defined by ANSI X9.62-2005 and RFC 3279 Section 2.2.3 for ECDSA.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "signature", b"signature"]) -> None: ...

global___AsymmetricSignResponse = AsymmetricSignResponse

@typing.final
class AsymmetricSignHashRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to use for signature."""
    hash: builtins.bytes
    """Hash value to be signed.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        hash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hash", b"hash", "key_id", b"key_id"]) -> None: ...

global___AsymmetricSignHashRequest = AsymmetricSignHashRequest

@typing.final
class AsymmetricSignHashResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key that was used for signature."""
    signature: builtins.bytes
    """Value of signature.
    Signature value is produced in accordance with RFC 8017 for RSA
    and is a DER-encoded object as defined by ANSI X9.62-2005 and RFC 3279 Section 2.2.3 for ECDSA.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "signature", b"signature"]) -> None: ...

global___AsymmetricSignHashResponse = AsymmetricSignHashResponse

@typing.final
class AsymmetricGetPublicKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to be used for public key retrieval."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___AsymmetricGetPublicKeyRequest = AsymmetricGetPublicKeyRequest

@typing.final
class AsymmetricGetPublicKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to get public key of."""
    public_key: builtins.str
    """Public key value.
    The value is a PEM-encoded X.509 public key, also known as SubjectPublicKeyInfo (SPKI),
    as defined in RFC 5280.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        public_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "public_key", b"public_key"]) -> None: ...

global___AsymmetricGetPublicKeyResponse = AsymmetricGetPublicKeyResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Tag(google.protobuf.message.Message):
    """Tag attached to some entity."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Key of the tag."""
    value: builtins.str
    """Value of the tag."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Tag = Tag



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Channel(google.protobuf.message.Message):
    """Root entity for content organization and separation within the video platform.
    A channel serves as a container for videos and streams, providing a way to
    group related content and apply common settings and access controls.
    Each channel belongs to a specific organization and can have its own
    configuration for advertisements, content cleanup, and embedding restrictions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the channel.
    This ID is used to reference the channel in API calls and URLs.
    """
    organization_id: builtins.str
    """Identifier of the organization to which this channel belongs.
    Each channel must be associated with exactly one organization.
    """
    title: builtins.str
    """Title of the channel displayed in interfaces.
    This is the primary display name shown to users.
    """
    description: builtins.str
    """Detailed description of the channel's purpose and content.
    This optional field provides additional context about the channel.
    """
    default_style_preset_id: builtins.str
    """Identifier of the default style preset applied to videos in this channel.
    Videos, episodes, and playlists created in this channel
    inherit this preset unless explicitly overridden.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the channel was initially created.
        This value is set automatically by the system and cannot be modified.
        """

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the channel or its settings.
        This value is updated automatically whenever the channel is modified.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as `key:value` pairs.
        Maximum 64 labels per channel.
        Labels can be used for organization, filtering, and metadata purposes.
        """

    @property
    def settings(self) -> global___ChannelSettings:
        """Configuration settings for the channel's behavior and features.
        These settings control advertisements, content cleanup policies,
        and embedding restrictions for all content in the channel.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        default_style_preset_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: global___ChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "settings", b"settings", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "default_style_preset_id", b"default_style_preset_id", "description", b"description", "id", b"id", "labels", b"labels", "organization_id", b"organization_id", "settings", b"settings", "title", b"title", "updated_at", b"updated_at"]) -> None: ...

global___Channel = Channel

@typing.final
class ChannelSettings(google.protobuf.message.Message):
    """Configuration settings for the channel's behavior and features.
    These settings apply to all content in the channel and control
    various aspects of how the channel and its content behave.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVERTISEMENT_FIELD_NUMBER: builtins.int
    REFERER_VERIFICATION_FIELD_NUMBER: builtins.int
    @property
    def advertisement(self) -> global___AdvertisementSettings:
        """Settings for advertisement display and behavior.
        Controls whether and how advertisements are shown with content in this channel.
        If not specified, default advertisement settings are applied.
        """

    @property
    def referer_verification(self) -> global___RefererVerificationSettings:
        """Settings for HTTP Referer verification to control content embedding.
        Restricts which domains can embed content from this channel.
        If not specified or disabled, content can be embedded on any domain.
        """

    def __init__(
        self,
        *,
        advertisement: global___AdvertisementSettings | None = ...,
        referer_verification: global___RefererVerificationSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advertisement", b"advertisement", "referer_verification", b"referer_verification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "referer_verification", b"referer_verification"]) -> None: ...

global___ChannelSettings = ChannelSettings

@typing.final
class AdvertisementSettings(google.protobuf.message.Message):
    """Settings for advertisement display and behavior in the channel.
    These settings control whether and how advertisements are shown
    with content in this channel, including both videos and streams.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class YandexDirect(google.protobuf.message.Message):
        """Configuration for the Yandex.Direct advertisement provider.
        These settings are specific to the Yandex.Direct advertising platform.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLE_FIELD_NUMBER: builtins.int
        PAGE_ID_FIELD_NUMBER: builtins.int
        CATEGORY_FIELD_NUMBER: builtins.int
        enable: builtins.bool
        """Enables or disables Partner Ad for both Live and VOD content.
        When set to true, advertisements will be shown with content.
        When set to false, no advertisements will be shown.
        """
        page_id: builtins.int
        """Yandex.Direct page identifier.
        This ID is used to associate the channel with a specific page
        in the Yandex.Direct system for targeting and reporting.
        """
        category: builtins.int
        """Yandex.Direct category identifier.
        This ID is used to categorize the channel's content for
        appropriate advertisement targeting and compliance.
        """
        def __init__(
            self,
            *,
            enable: builtins.bool = ...,
            page_id: builtins.int = ...,
            category: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["category", b"category", "enable", b"enable", "page_id", b"page_id"]) -> None: ...

    YANDEX_DIRECT_FIELD_NUMBER: builtins.int
    @property
    def yandex_direct(self) -> global___AdvertisementSettings.YandexDirect:
        """Yandex.Direct advertisement provider settings.
        When specified, advertisements will be served through Yandex.Direct.
        """

    def __init__(
        self,
        *,
        yandex_direct: global___AdvertisementSettings.YandexDirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["provider", b"provider", "yandex_direct", b"yandex_direct"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["provider", b"provider", "yandex_direct", b"yandex_direct"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["provider", b"provider"]) -> typing.Literal["yandex_direct"] | None: ...

global___AdvertisementSettings = AdvertisementSettings

@typing.final
class RefererVerificationSettings(google.protobuf.message.Message):
    """Settings for HTTP Referer verification to control where content can be embedded.
    When enabled, the system checks the HTTP Referer request header to ensure
    that content is only embedded on allowed domains.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    ALLOWED_DOMAINS_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    """Enables or disables Referer verification for this channel.
    When set to true, only requests from allowed domains will be permitted.
    When set to false, content can be embedded on any domain.
    """
    @property
    def allowed_domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of domains allowed to embed content from this channel.
        Only relevant when enable is set to true.
        Supports wildcard notation (e.g., "*.example.com") to allow all subdomains.
        """

    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        allowed_domains: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allowed_domains", b"allowed_domains", "enable", b"enable"]) -> None: ...

global___RefererVerificationSettings = RefererVerificationSettings
